Module bindings

Module bindings 

Modules

errors

Structs

Asio
A handle to the ASIO API.
AsioBufferInfo
Gives information about buffers Receives pointers to buffers
AsioStream
A stream to ASIO.
AsioStreams
Input and Output streams.
AsioTime
A rust-usable version of the ASIOTime type that does not contain a binary blob for fields.
AsioTimeCode
A rust-compatible version of the ASIOTimeCode type that does not use a binary blob for its fields.
AsioTimeInfo
A rust-compatible version of the ASIOTimeInfo type that does not contain a binary blob for fields.
BufferCallbackId
Identifies a buffer callback registered via Driver::add_callback.
BufferSizeRange
Minimum and maximum supported buffer sizes in frames.
CallbackInfo
Information provided to the BufferCallback.
Channels
Amount of input and output channels available.
Driver
A handle to a single ASIO driver.
DriverEventCallbackId
Identifies a driver event callback registered via Driver::add_event_callback.
Latencies
Hardware latency in frames for the input and output streams.

Enums

AsioDriverEvent
Events dispatched to registered driver event callbacks.
AsioMessageSelectors
All the possible types from ASIO. This is a direct copy of the asioMessage selectors inside ASIO SDK.
AsioSampleType
All the possible types from ASIO. This is a direct copy of the ASIOSampleType inside ASIO SDK.
BufferPreference
Hardware buffer size preferences and constraints.

Type Aliases

AsioSampleRate
A rust-compatible version of the ASIOSampleRate type that does not use a binary blob for its fields.