Modules
Structs
- Asio
- A handle to the ASIO API.
- Asio
Buffer Info - Gives information about buffers Receives pointers to buffers
- Asio
Stream - A stream to ASIO.
- Asio
Streams - Input and Output streams.
- Asio
Time - A rust-usable version of the
ASIOTimetype that does not contain a binary blob for fields. - Asio
Time Code - A rust-compatible version of the
ASIOTimeCodetype that does not use a binary blob for its fields. - Asio
Time Info - A rust-compatible version of the
ASIOTimeInfotype that does not contain a binary blob for fields. - Buffer
Callback Id - Identifies a buffer callback registered via
Driver::add_callback. - Buffer
Size Range - Minimum and maximum supported buffer sizes in frames.
- Callback
Info - Information provided to the BufferCallback.
- Channels
- Amount of input and output channels available.
- Driver
- A handle to a single ASIO driver.
- Driver
Event Callback Id - Identifies a driver event callback registered via
Driver::add_event_callback. - Latencies
- Hardware latency in frames for the input and output streams.
Enums
- Asio
Driver Event - Events dispatched to registered driver event callbacks.
- Asio
Message Selectors - All the possible types from ASIO. This is a direct copy of the asioMessage selectors inside ASIO SDK.
- Asio
Sample Type - All the possible types from ASIO. This is a direct copy of the ASIOSampleType inside ASIO SDK.
- Buffer
Preference - Hardware buffer size preferences and constraints.
Type Aliases
- Asio
Sample Rate - A rust-compatible version of the
ASIOSampleRatetype that does not use a binary blob for its fields.